Changelog
=========


0.1.1 (2015-02-06)
------------------

- Bugfix on ``rlink()``


0.1.0 (2015-02-06)
------------------

- tags and category support has been removed.  Instead, the generic functions
  ``by_key`` and ``values`` have been introduced.
- Additional files in root folder may now also be directories.


0.0.2 (2014-06-14)
------------------

- Default destination depends on source.
- Any additional files from the root folder that do not begin with
  an underscore (``_``) or dot (``.``) will be copied verbatim.


0.0.1 (2014-06-14)
------------------

- initial release
